AuthBaton

Struct AuthBaton 

pub struct AuthBaton { /* private fields */ }
Authentication baton for managing authentication providers and credentials.

Implementations

Source

impl AuthBaton

pub fn as_mut_ptr(&mut self) -> *mut svn_auth_baton_t

Returns a mutable pointer to the auth baton.

pub fn set(&mut self, setting: AuthSetting<'_>) -> Result<(), Error<'static>>

Sets an authentication setting.

pub fn credentials<C: Credentials>( &mut self, realm: &str, ) -> Result<IterState<C>, Error<'_>>

Gets credentials for the specified realm.

pub fn forget_credentials<C: Credentials>( &mut self, cred_kind: Option<&str>, realm: Option<&str>, ) -> Result<(), Error<'static>>

Forgets stored credentials.

pub unsafe fn get_parameter(&mut self, name: &str) -> *const c_void

Get a parameter from the auth baton.

Safety

The caller must ensure that the value is valid for the lifetime of the auth baton.

pub unsafe fn set_parameter(&mut self, name: &str, value: *const c_void)

Set a parameter on the auth baton.

Safety

The caller must ensure that the value is valid for the lifetime of the auth baton.

pub fn open(providers: Vec<AuthProvider>) -> Result<Self, Error<'static>>

Opens an authentication baton with the given providers.