DeleteOptions

Struct DeleteOptions 

pub struct DeleteOptions<'a> {
    pub force: bool,
    pub keep_local: bool,
    pub commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>,
}
Options for delete Options for deleting versioned items.

Fields

force: bool

Whether to force deletion even if there are local modifications.

keep_local: bool

Whether to keep the local copy of the file.

commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>

Optional callback to invoke after commit.

Implementations

Source

impl<'a> DeleteOptions<'a>

pub fn new() -> Self

Creates a new DeleteOptions with default values.

pub fn with_force(self, force: bool) -> Self

Sets whether to force deletion.

pub fn with_keep_local(self, keep_local: bool) -> Self

Sets whether to keep the local copy.

pub fn with_commit_callback( self, callback: &'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>, ) -> Self

Sets the commit callback.