DiffBuilder

Struct DiffBuilder 

pub struct DiffBuilder<'a> { /* private fields */ }
Builder for diff operations Builder for creating diff operations with various options.

Implementations

Source

impl<'a> DiffBuilder<'a>

pub fn new( ctx: &'a mut Context, path1: impl Into<String>, revision1: Revision, path2: impl Into<String>, revision2: Revision, ) -> Self

Creates a new DiffBuilder for comparing two paths/revisions.

pub fn depth(self, depth: Depth) -> Self

Sets the depth for the diff operation.

pub fn diff_options(self, options: Vec<String>) -> Self

Sets additional options to pass to the diff command.

pub fn relative_to_dir(self, dir: impl Into<String>) -> Self

Sets the directory to make paths relative to.

pub fn ignore_ancestry(self, ignore: bool) -> Self

Sets whether to ignore ancestry when comparing.

pub fn no_diff_added(self, no_diff: bool) -> Self

Sets whether to omit diffs for added files.

pub fn no_diff_deleted(self, no_diff: bool) -> Self

Sets whether to omit diffs for deleted files.

pub fn show_copies_as_adds(self, show: bool) -> Self

Sets whether to show copies as additions.

pub fn ignore_content_type(self, ignore: bool) -> Self

Sets whether to ignore content type differences.

pub fn ignore_properties(self, ignore: bool) -> Self

Sets whether to ignore property differences.

pub fn properties_only(self, only: bool) -> Self

Sets whether to show only property differences.

pub fn use_git_diff_format(self, use_git: bool) -> Self

Sets whether to use Git diff format.

pub fn header_encoding(self, encoding: impl Into<String>) -> Self

Sets the encoding for diff headers.

pub fn changelists(self, lists: Vec<String>) -> Self

Sets the changelists to include in the diff.

pub fn execute( self, outstream: &mut Stream, errstream: &mut Stream, ) -> Result<(), Error<'static>>

Executes the diff operation.