ImportOptions

Struct ImportOptions 

pub struct ImportOptions<'a> {
    pub depth: Depth,
    pub no_ignore: bool,
    pub no_autoprops: bool,
    pub ignore_unknown_node_types: bool,
    pub revprop_table: Option<HashMap<String, String>>,
    pub filter_callback: Option<&'a mut dyn FnMut(&mut bool, &Path, &Dirent) -> Result<(), Error<'static>>>,
    pub commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>,
}
Options for import operations

Fields

depth: Depth

Recursion depth.

no_ignore: bool

If true, don’t use default ignores.

no_autoprops: bool

If true, don’t use auto-props.

ignore_unknown_node_types: bool

If true, ignore unknown node types instead of erroring.

revprop_table: Option<HashMap<String, String>>

Revision properties for the commit.

filter_callback: Option<&'a mut dyn FnMut(&mut bool, &Path, &Dirent) -> Result<(), Error<'static>>>

Optional filter callback to control which files are imported.

commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>

Optional callback to invoke after commit.

Implementations

Source

impl<'a> ImportOptions<'a>

pub fn new() -> Self

Creates a new ImportOptions with default values.

pub fn with_depth(self, depth: Depth) -> Self

Sets the depth for the import.

pub fn with_no_ignore(self, no_ignore: bool) -> Self

Sets whether to ignore default ignores.

pub fn with_no_autoprops(self, no_autoprops: bool) -> Self

Sets whether to disable auto-props.

pub fn with_ignore_unknown_node_types(self, ignore: bool) -> Self

Sets whether to ignore unknown node types.

pub fn with_revprop_table(self, revprops: HashMap<String, String>) -> Self

Sets the revision properties.

pub fn with_filter_callback( self, callback: &'a mut dyn FnMut(&mut bool, &Path, &Dirent) -> Result<(), Error<'static>>, ) -> Self

Sets the filter callback.

pub fn with_commit_callback( self, callback: &'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>, ) -> Self

Sets the commit callback.