Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration container wrapping svn_config_t

Implementations

Source

impl Config

pub fn get( &self, option: ConfigOption<'_>, ) -> Result<ConfigValue, Error<'static>>

Get a configuration option value

pub fn set(&mut self, option: ConfigOption<'_>) -> Result<(), Error<'static>>

Set a configuration option

pub fn as_ptr(&self) -> *const svn_config_t

Returns a raw pointer to the configuration.

pub fn as_mut_ptr(&mut self) -> *mut svn_config_t

Returns a mutable raw pointer to the configuration.

pub fn enumerate_sections<F>(&self, callback: F) -> i32
where F: FnMut(&str) -> bool,

Enumerate all sections in this configuration.

Calls callback with each section name. Return true from the callback to continue enumeration, false to stop. Returns the number of times the callback was invoked.

pub fn enumerate<F>( &self, section: &str, callback: F, ) -> Result<i32, Error<'static>>
where F: FnMut(&str, &str) -> bool,

Enumerate all options in the given section.

Calls callback with each option name and value. Return true from the callback to continue enumeration, false to stop. Returns the number of times the callback was invoked.

pub fn has_section(&self, section: &str) -> Result<bool, Error<'static>>

Check if a section exists in this configuration.