target_push

Function target_push 

pub unsafe fn target_push(
    handler: svn_txdelta_window_handler_t,
    handler_baton: *mut c_void,
    source: &mut Stream,
) -> Stream 
Create a push-based delta target stream

Returns a writable stream which, when fed target data, will send delta windows to the provided handler that transform the source data to the target data.

Safety

The caller must ensure that handler and handler_baton are valid and compatible.

Wraps svn_txdelta_target_push.