TxDeltaWindow

Struct TxDeltaWindow 

pub struct TxDeltaWindow { /* private fields */ }
TxDelta window with RAII cleanup

Implementations

Source

impl TxDeltaWindow

pub fn pool(&self) -> &Pool<'_>

Get a reference to the underlying pool

pub fn as_mut_ptr(&mut self) -> *mut svn_txdelta_window_t

Get the mutable raw pointer to the window (use with caution)

pub fn as_ptr(&self) -> *const svn_txdelta_window_t

Get the raw pointer to the window.

pub fn new() -> Self

Creates a new TxDelta window.

pub fn from_parts( sview_offset: u64, sview_len: u64, tview_len: u64, src_ops: i32, ops: &[(i32, u64, u64)], new_data: &[u8], ) -> Self

Creates a TxDelta window from constituent parts.

Arguments
  • sview_offset - Source view offset
  • sview_len - Source view length
  • tview_len - Target view length
  • src_ops - Number of source operations (usually ignored)
  • ops - Delta operations as (action_code, offset, length) tuples
  • new_data - New data buffer
pub fn sview_len(&self) -> apr_size_t

Gets the source view length.

pub fn tview_len(&self) -> apr_size_t

Gets the target view length.

pub fn sview_offset(&self) -> FileSize

Gets the source view offset.

pub fn src_ops(&self) -> i32

Gets the number of source operations.

pub fn ops(&self) -> Vec<(i32, u64, u64)>

Gets the delta operations as (action_code, offset, length) tuples.

pub fn new_data(&self) -> &[u8]

Gets the new data buffer.

pub fn compose(a: &Self, b: &Self) -> Self

Composes two TxDelta windows.

pub fn apply_instructions( &mut self, source: &mut [u8], target: &mut Vec<u8>, ) -> Result<(), Error<'_>>

Applies the window instructions to transform source to target.

pub fn dup(&self) -> Self

Creates a duplicate of the window.