pub struct DiffHunk { /* private fields */ }Expand description
A diff hunk showing differences between files
Implementations
Sourceimpl DiffHunk
impl DiffHunk
Sourcepub fn original_start(&self) -> u64
pub fn original_start(&self) -> u64
Get the starting line number in the original file
Sourcepub fn original_length(&self) -> u64
pub fn original_length(&self) -> u64
Get the number of lines in the original file
Sourcepub fn modified_start(&self) -> u64
pub fn modified_start(&self) -> u64
Get the starting line number in the modified file
Sourcepub fn modified_length(&self) -> u64
pub fn modified_length(&self) -> u64
Get the number of lines in the modified file
Sourcepub fn leading_context(&self) -> u64
pub fn leading_context(&self) -> u64
Get the leading context lines
Sourcepub fn trailing_context(&self) -> u64
pub fn trailing_context(&self) -> u64
Get the trailing context lines