Module error

Module error 

Error handling types and utilities.

Structs

Error
Represents a Subversion error.

Enums

ErrorCategory
Categorizes the kind of error that occurred based on SVN error code ranges.

Functions

strerror
Gets a human-readable error string for a status code.
symbolic_name
Gets the symbolic name for an error status code.