Module hash

Module hash 

Hash table utilities. Hash table serialization and utilities

This module provides safe Rust wrappers around Subversion’s hash table utilities for reading, writing, and manipulating hash tables to/from streams.

Structs

DirentHash
A safe wrapper for APR hashes containing path -> svn_dirent_t mappings
FsDirentHash
A safe wrapper for APR hashes containing path -> svn_fs_dirent_t mappings
PathChangeHash
A safe wrapper for APR hashes containing path -> svn_fs_path_change2_t mappings

Enums

DiffKeyStatus
Hash difference key status

Functions

diff
Compare two hash tables and call a function for each differing key
from_cstring_keys
Create a hash table from an array of C string keys
read
Read hash data from a stream into a hash table
read_incremental
Read hash data incrementally from stream, allowing deletions
write
Write hash data to a stream
write_incremental
Write hash data incrementally to stream