Builder pattern for creating streams with custom configurations
Structs
- Stream
Builder - Builder for creating streams with custom backends and configurations
Traits
- Into
Stream - Extension trait for creating streams from various types
Functions
- buffered_
stream - Helper to create a buffered stream
- lazy_
stream - Helper to create a lazy stream that opens on first use