pub struct MergeinfoCatalog { /* private fields */ }Expand description
A catalog of mergeinfo, mapping paths to their mergeinfo.
This is essentially a hash table where keys are repository paths and values are Mergeinfo objects.
Implementations
Sourceimpl MergeinfoCatalog
impl MergeinfoCatalog
Sourcepub fn merge(
&mut self,
changes: &MergeinfoCatalog,
) -> Result<(), Error<'static>>
pub fn merge( &mut self, changes: &MergeinfoCatalog, ) -> Result<(), Error<'static>>
Merge changes from another catalog into this one.
Sourcepub fn dup(&self) -> MergeinfoCatalog
pub fn dup(&self) -> MergeinfoCatalog
Duplicate this catalog.