Reporter

Trait Reporter 

pub trait Reporter {
    // Required methods
    fn set_path(
        &mut self,
        path: &str,
        rev: Revnum,
        depth: Depth,
        start_empty: bool,
        lock_token: &str,
    ) -> Result<(), Error<'static>>;
    fn delete_path(&mut self, path: &str) -> Result<(), Error<'static>>;
    fn link_path(
        &mut self,
        path: &str,
        url: &str,
        rev: Revnum,
        depth: Depth,
        start_empty: bool,
        lock_token: &str,
    ) -> Result<(), Error<'static>>;
    fn finish_report(&mut self) -> Result<(), Error<'static>>;
    fn abort_report(&mut self) -> Result<(), Error<'static>>;
}
Trait for reporting working copy state to the repository.

Required Methods

fn set_path( &mut self, path: &str, rev: Revnum, depth: Depth, start_empty: bool, lock_token: &str, ) -> Result<(), Error<'static>>

Reports the state of a path in the working copy.

fn delete_path(&mut self, path: &str) -> Result<(), Error<'static>>

Reports that a path has been deleted from the working copy.

Links a path to a URL in the repository.

fn finish_report(&mut self) -> Result<(), Error<'static>>

Finishes the report and triggers the update/diff.

fn abort_report(&mut self) -> Result<(), Error<'static>>

Aborts the report without triggering the update/diff.

Implementors