OwnedLogEntry

Struct OwnedLogEntry 

pub struct OwnedLogEntry { /* private fields */ }
A log entry that owns its backing memory pool.

Created by log iterator APIs to allow log entries to be sent across threads and outlive the callback scope they were created in.

Implementations

Source

impl OwnedLogEntry

pub fn from_log_entry(entry: &LogEntry<'_>) -> Self

Create an owned copy of a log entry by duplicating it into a new pool.

Methods from Deref<Target = LogEntry<'static>>

pub fn dup( &self, pool: &'pool Pool<'pool>, ) -> Result<LogEntry<'pool>, Error<'_>>

Duplicates the log entry in the given pool.

pub fn as_ptr(&self) -> *const svn_log_entry_t

Returns the raw pointer to the log entry.

pub fn revision(&self) -> Option<Revnum>

Get the revision number

pub fn message(&self) -> Option<&str>

Get the log message

pub fn author(&self) -> Option<&str>

Get the author

pub fn date(&self) -> Option<&str>

Get the date as a string

pub fn has_children(&self) -> bool

Check if this log entry has children

pub fn non_inheritable(&self) -> bool

Whether this revision should be interpreted as non-inheritable

Only set when this log entry is returned by the mergeinfo APIs.

pub fn subtractive_merge(&self) -> bool

Whether this revision is a merged revision resulting from a reverse merge

pub fn revprops(&self) -> HashMap<String, Vec<u8>>

Get all revision properties as a HashMap

pub fn changed_paths(&self) -> Option<HashMap<String, LogChangedPath>>

Get the changed paths for this log entry

Returns None if changed paths were not requested in the log operation.