PropChange

Struct PropChange 

pub struct PropChange {
    pub name: String,
    pub value: Option<Vec<u8>>,
}
Represents a property change in the working copy

A property change consists of a property name and an optional value. If the value is None, it indicates the property has been deleted.

Fields

name: String

The name of the property

value: Option<Vec<u8>>

The new value of the property, or None if deleted