pub struct DeleteOptions<'a> {
pub force: bool,
pub keep_local: bool,
pub commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>,
}Expand description
Options for delete Options for deleting versioned items.
Fields
force: boolWhether to force deletion even if there are local modifications.
keep_local: boolWhether to keep the local copy of the file.
commit_callback: Option<&'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>>Optional callback to invoke after commit.
Implementations
Sourceimpl<'a> DeleteOptions<'a>
impl<'a> DeleteOptions<'a>
Sourcepub fn with_force(self, force: bool) -> Self
pub fn with_force(self, force: bool) -> Self
Sets whether to force deletion.
Sourcepub fn with_keep_local(self, keep_local: bool) -> Self
pub fn with_keep_local(self, keep_local: bool) -> Self
Sets whether to keep the local copy.
Sourcepub fn with_commit_callback(
self,
callback: &'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>,
) -> Self
pub fn with_commit_callback( self, callback: &'a mut dyn FnMut(&CommitInfo<'_>) -> Result<(), Error<'static>>, ) -> Self
Sets the commit callback.