pub struct Config { /* private fields */ }Expand description
Configuration container wrapping svn_config_t
Implementations
Sourceimpl Config
impl Config
Sourcepub fn get(
&self,
option: ConfigOption<'_>,
) -> Result<ConfigValue, Error<'static>>
pub fn get( &self, option: ConfigOption<'_>, ) -> Result<ConfigValue, Error<'static>>
Get a configuration option value
Sourcepub fn set(&mut self, option: ConfigOption<'_>) -> Result<(), Error<'static>>
pub fn set(&mut self, option: ConfigOption<'_>) -> Result<(), Error<'static>>
Set a configuration option
Sourcepub fn as_ptr(&self) -> *const svn_config_t
pub fn as_ptr(&self) -> *const svn_config_t
Returns a raw pointer to the configuration.
Sourcepub fn as_mut_ptr(&mut self) -> *mut svn_config_t
pub fn as_mut_ptr(&mut self) -> *mut svn_config_t
Returns a mutable raw pointer to the configuration.
Sourcepub fn enumerate_sections<F>(&self, callback: F) -> i32
pub fn enumerate_sections<F>(&self, callback: F) -> i32
Enumerate all sections in this configuration.
Calls callback with each section name. Return true from the
callback to continue enumeration, false to stop.
Returns the number of times the callback was invoked.
Sourcepub fn enumerate<F>(
&self,
section: &str,
callback: F,
) -> Result<i32, Error<'static>>
pub fn enumerate<F>( &self, section: &str, callback: F, ) -> Result<i32, Error<'static>>
Enumerate all options in the given section.
Calls callback with each option name and value. Return true from
the callback to continue enumeration, false to stop.
Returns the number of times the callback was invoked.