Error handling types and utilities.
Structs
- Error
- Represents a Subversion error.
Enums
- Error
Category - Categorizes the kind of error that occurred based on SVN error code ranges.
Functions
- strerror
- Gets a human-readable error string for a status code.
- symbolic_
name - Gets the symbolic name for an error status code.