UpgradeAction

Enum UpgradeAction 

pub enum UpgradeAction {
    PackRevprops,
    CleanupRevprops,
    FormatBumped,
}
The type of notification action during a filesystem upgrade.

Used with the notify callback of upgrade().

Variants



PackRevprops

Packing of revision properties for a shard has completed.



CleanupRevprops

Removal of the non-packed revprop shard has completed.



FormatBumped

The database format has been set to a new value.