pub struct FsPath { /* private fields */ }Expand description
A canonical absolute filesystem path for use with Subversion filesystem operations.
SVN filesystem paths must be canonical and absolute (start with ‘/’). This type ensures paths are properly canonicalized using SVN’s own canonicalization functions.
Implementations
Sourceimpl FsPath
impl FsPath
Sourcepub fn from_canonical(path: &str) -> Result<Self, Error<'static>>
pub fn from_canonical(path: &str) -> Result<Self, Error<'static>>
Create an FsPath from an already-canonical path.
This is a fast path that only validates the path is canonical. Returns an error if the path is not canonical.
Sourcepub fn canonicalize(path: &str) -> Result<Self, Error<'static>>
pub fn canonicalize(path: &str) -> Result<Self, Error<'static>>
Create an FsPath by canonicalizing the input path.
This will canonicalize the path using SVN’s canonicalization rules. Returns an error if the path cannot be made canonical.