pub struct FsPathChange { /* private fields */ }Expand description
Represents a change to a path in the filesystem
Implementations
Sourceimpl FsPathChange
impl FsPathChange
Sourcepub fn from_raw(ptr: *mut svn_fs_path_change2_t) -> Self
pub fn from_raw(ptr: *mut svn_fs_path_change2_t) -> Self
Creates an FsPathChange from a raw pointer.
Sourcepub fn change_kind(&self) -> FsPathChangeKind
pub fn change_kind(&self) -> FsPathChangeKind
Gets the kind of change for this path.
Sourcepub fn text_modified(&self) -> bool
pub fn text_modified(&self) -> bool
Checks if the text content was modified.
Sourcepub fn props_modified(&self) -> bool
pub fn props_modified(&self) -> bool
Checks if properties were modified.
Sourcepub fn copyfrom_path(&self) -> Option<String>
pub fn copyfrom_path(&self) -> Option<String>
Gets the path this was copied from, if any.
Sourcepub fn copyfrom_rev(&self) -> Option<Revnum>
pub fn copyfrom_rev(&self) -> Option<Revnum>
Gets the revision this was copied from, if any.