pub fn read_incremental(
stream: &mut Stream,
terminator: Option<&str>,
) -> Result<HashMap<String, String>, Error<'static>>Expand description
Read hash data incrementally from stream, allowing deletions
Similar to read() but allows stream to contain deletion lines which remove entries from the hash as well as adding to it.