pub struct PathChangeHash<'a> { /* private fields */ }Expand description
A safe wrapper for APR hashes containing path -> svn_fs_path_change2_t mappings
This wrapper encapsulates the common pattern of working with changed path hashes from Subversion’s FS API.
Implementations
Sourceimpl<'a> PathChangeHash<'a>
impl<'a> PathChangeHash<'a>
Sourcepub unsafe fn from_ptr(ptr: *mut apr_hash_t) -> Self
pub unsafe fn from_ptr(ptr: *mut apr_hash_t) -> Self
Create a PathChangeHash from a raw APR hash pointer
Safety
The caller must ensure that:
ptris a valid APR hash containing svn_fs_path_change2_t values- The hash and its contents remain valid for the lifetime of this wrapper
Sourcepub fn to_hashmap(&self) -> HashMap<String, FsPathChange>
pub fn to_hashmap(&self) -> HashMap<String, FsPathChange>
Convert the path changes to a HashMap<String, FsPathChange>