pub trait Reporter {
// Required methods
fn set_path(
&mut self,
path: &str,
rev: Revnum,
depth: Depth,
start_empty: bool,
lock_token: &str,
) -> Result<(), Error<'static>>;
fn delete_path(&mut self, path: &str) -> Result<(), Error<'static>>;
fn link_path(
&mut self,
path: &str,
url: &str,
rev: Revnum,
depth: Depth,
start_empty: bool,
lock_token: &str,
) -> Result<(), Error<'static>>;
fn finish_report(&mut self) -> Result<(), Error<'static>>;
fn abort_report(&mut self) -> Result<(), Error<'static>>;
}Expand description
Trait for reporting working copy state to the repository.
Required Methods
Sourcefn set_path(
&mut self,
path: &str,
rev: Revnum,
depth: Depth,
start_empty: bool,
lock_token: &str,
) -> Result<(), Error<'static>>
fn set_path( &mut self, path: &str, rev: Revnum, depth: Depth, start_empty: bool, lock_token: &str, ) -> Result<(), Error<'static>>
Reports the state of a path in the working copy.
Sourcefn delete_path(&mut self, path: &str) -> Result<(), Error<'static>>
fn delete_path(&mut self, path: &str) -> Result<(), Error<'static>>
Reports that a path has been deleted from the working copy.
Sourcefn link_path(
&mut self,
path: &str,
url: &str,
rev: Revnum,
depth: Depth,
start_empty: bool,
lock_token: &str,
) -> Result<(), Error<'static>>
fn link_path( &mut self, path: &str, url: &str, rev: Revnum, depth: Depth, start_empty: bool, lock_token: &str, ) -> Result<(), Error<'static>>
Links a path to a URL in the repository.
Sourcefn finish_report(&mut self) -> Result<(), Error<'static>>
fn finish_report(&mut self) -> Result<(), Error<'static>>
Finishes the report and triggers the update/diff.
Sourcefn abort_report(&mut self) -> Result<(), Error<'static>>
fn abort_report(&mut self) -> Result<(), Error<'static>>
Aborts the report without triggering the update/diff.