pub struct OwnedLogEntry { /* private fields */ }Expand description
A log entry that owns its backing memory pool.
Created by log iterator APIs to allow log entries to be sent across threads and outlive the callback scope they were created in.
Implementations
Sourceimpl OwnedLogEntry
impl OwnedLogEntry
Sourcepub fn from_log_entry(entry: &LogEntry<'_>) -> Self
pub fn from_log_entry(entry: &LogEntry<'_>) -> Self
Create an owned copy of a log entry by duplicating it into a new pool.
Methods from Deref<Target = LogEntry<'static>>
Sourcepub fn dup(
&self,
pool: &'pool Pool<'pool>,
) -> Result<LogEntry<'pool>, Error<'_>>
pub fn dup( &self, pool: &'pool Pool<'pool>, ) -> Result<LogEntry<'pool>, Error<'_>>
Duplicates the log entry in the given pool.
Sourcepub fn as_ptr(&self) -> *const svn_log_entry_t
pub fn as_ptr(&self) -> *const svn_log_entry_t
Returns the raw pointer to the log entry.
Get the author
Sourcepub fn has_children(&self) -> bool
pub fn has_children(&self) -> bool
Check if this log entry has children
Sourcepub fn non_inheritable(&self) -> bool
pub fn non_inheritable(&self) -> bool
Whether this revision should be interpreted as non-inheritable
Only set when this log entry is returned by the mergeinfo APIs.
Sourcepub fn subtractive_merge(&self) -> bool
pub fn subtractive_merge(&self) -> bool
Whether this revision is a merged revision resulting from a reverse merge
Sourcepub fn changed_paths(&self) -> Option<HashMap<String, LogChangedPath>>
pub fn changed_paths(&self) -> Option<HashMap<String, LogChangedPath>>
Get the changed paths for this log entry
Returns None if changed paths were not requested in the log operation.