pub struct PropChange {
pub name: String,
pub value: Option<Vec<u8>>,
}Expand description
Represents a property change in the working copy
A property change consists of a property name and an optional value. If the value is None, it indicates the property has been deleted.
Fields
name: StringThe name of the property
value: Option<Vec<u8>>The new value of the property, or None if deleted